==> eoaLocation-1.0.4-sources.jar: com/xdja/location/ImageBean.java <==
package com.xdja.location;

import java.io.Serializable;

/**
 * created on 2017/8/28.
 * author:wangkezhi
 * email:45436660@qq.com
 * summary:
 */

public class ImageBean implements Serializable{
    public enum TYPE {IMAGE, VIDEO}
    private String path;
    private boolean isSelected;
    private boolean isYt;
    private String miniMap;
    private String scalePath;
    private TYPE type = TYPE.IMAGE;
    private int modifyTime;
    private String url;

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public int getModifyTime() {
        return modifyTime;
    }

    public void setModifyTime(int modifyTime) {
        this.modifyTime = modifyTime;
    }

    public TYPE getType() {
        return type;
    }

    public void setType(TYPE type) {
        this.type = type;
    }

    public String getPath() {
        return path;
    }

    public void setPath(String path) {
        this.path = path;
    }

    public boolean isSelected() {
        return isSelected;
    }

    public void setSelected(boolean isSelected) {
        this.isSelected = isSelected;
    }

    public boolean isYt() {
        return isYt;
    }

    public void setYt(boolean isYt) {
        this.isYt = isYt;
    }

    public String getMiniMap() {
        return miniMap;
    }

    public void setMiniMap(String miniMap) {
        this.miniMap = miniMap;
    }

    public String getScalePath() {
        return scalePath;
    }

    public void setScalePath(String scalePath) {
        this.scalePath = scalePath;
    }
}

==> eoaLocation-1.0.6-20200825.033707-2-sources.jar: com/xdja/location/ImageBean.java <==
package com.xdja.location;

import java.io.Serializable;

/**
 * @author wangkezhi
 * @date 2017/8/28
 */
public class ImageBean implements Serializable {
    public enum TYPE {
        /**
         * 图片
         */
        IMAGE,
        /**
         * 视频
         */
        VIDEO
    }

    private String path;
    private boolean isSelected;
    private boolean isYt;
    private String miniMap;
    private String scalePath;
    private TYPE type = TYPE.IMAGE;
    private int modifyTime;
    private String url;

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public int getModifyTime() {
        return modifyTime;
    }

    public void setModifyTime(int modifyTime) {
        this.modifyTime = modifyTime;
    }

    public TYPE getType() {
        return type;
    }

    public void setType(TYPE type) {
        this.type = type;
    }

    public String getPath() {
        return path;
    }

    public void setPath(String path) {
        this.path = path;
    }

    public boolean isSelected() {
        return isSelected;
    }

    public void setSelected(boolean isSelected) {
        this.isSelected = isSelected;
    }

    public boolean isYt() {
        return isYt;
    }

    public void setYt(boolean isYt) {
        this.isYt = isYt;
    }

    public String getMiniMap() {
        return miniMap;
    }

    public void setMiniMap(String miniMap) {
        this.miniMap = miniMap;
    }

    public String getScalePath() {
        return scalePath;
    }

    public void setScalePath(String scalePath) {
        this.scalePath = scalePath;
    }
}
